import type { RequestHandler } from '@sveltejs/kit';
import type { Metar } from '$lib/api/types/metar';

export const GET: RequestHandler = async ({ params }) => {
    const icao = params.icao?.toUpperCase();
    if (!icao || icao.length !== 4) {
        return new Response(JSON.stringify({ error: 'Invalid ICAO' }), { status: 400 });
    }

    const url = `https://aviationweather.gov/api/data/metar?ids=${icao}&format=json`;
    const res = await fetch(url);
    if (!res.ok) {
        return new Response(JSON.stringify({ error: 'Failed to fetch METAR' }), { status: 502 });
    }
    const data: Metar[] = await res.json();
    return new Response(JSON.stringify(data[0] ?? null), {
        headers: { 'Content-Type': 'application/json' }
    });
};